@@ -16,7 +16,7 @@ NULL
 
 load_task_zoo = function(id = "zoo") {
   b = as_data_backend(load_dataset("Zoo", "mlbench", keep_rownames = TRUE), keep_rownames = "animal")
-  task = TaskClassif$new(id, b, target = "type")
+  task = TaskClassif$new(id, b, target = "type", label = "Zoo Animals")
   b$hash = task$man = "mlr3::mlr_tasks_zoo"
   task$col_roles$name = "animal"
   task$col_roles$feature = setdiff(task$col_roles$feature, "animal")
