@@ -109,7 +109,7 @@ test_that("convert_task reconstructs task", {
   tsk2 = convert_task(task2)
   expect_equal(task2$nrow, tsk2$nrow)
   expect_equal(task2$ncol, tsk2$ncol)
-  expect_true("twoclass" %in% tsk2$properties)
+  expect_true("twoclass" %chin% tsk2$properties)
 
   task3 = task2
   task3$row_roles$use = 1:150
@@ -117,7 +117,7 @@ test_that("convert_task reconstructs task", {
   tsk3$man = "mlr3::mlr_tasks_iris"
   expect_equal(task3$nrow, tsk3$nrow)
   expect_equal(task3$ncol, tsk3$ncol)
-  expect_true("multiclass" %in% tsk3$properties)
+  expect_true("multiclass" %chin% tsk3$properties)
   expect_equal(task, tsk3, ignore_attr = TRUE)
 })
 
